@@ -23,7 +23,7 @@ my $prebuilt_binaries = [
       url      => 'http://www.cmake.org/files/v2.8/cmake-2.8.12.1-win32-x86.zip',
       version  => '2.8.12.1',
       sha1sum  => '6a27d8fcf887774e56fa165eddd5242e1c350464',
-      arch_re  => qr/^MSWin32-x(86|64)-multi-thread$/,
+      arch_re  => qr/^MSWin32-x(86|64)-multi-thread(-64int)?$/,
       os_re    => qr/^MSWin32$/
     },
     {
